@@ -11,7 +11,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
 """
 Top-level file for xformer.
 """
@@ -19,4 +18,4 @@ Top-level file for xformer.
 from ._errors import IntoDPError
 from ._signature import signature
 from ._xformer import xformer
-from ._xformer import ToDbusXformer
+from ._xformer import xformers
